Classes
-------

.. toctree::
   IMTreatment.core.points
   IMTreatment.core.profile
   IMTreatment.core.scalarfield
   IMTreatment.core.vectorfield
   IMTreatment.core.temporalscalarfields
   IMTreatment.core.temporalvectorfields
   IMTreatment.core.spatialscalarfields
   IMTreatment.core.spatialvectorfields
